@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Nokia Corporation, all rights reserved.
+ * Copyright (C) 2009 Nokia Corporation.
  *
  * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *                               <zeeshan.ali@nokia.com>
@@ -158,21 +158,18 @@ create_loopback_context (gpointer data)
 {
         GUPnPNetworkManager *manager = (GUPnPNetworkManager *) data;
         GUPnPContext *context;
-        GMainContext *main_context;
         guint port;
         GError *error = NULL;
 
         manager->priv->idle_context_creation_src = NULL;
 
         g_object_get (manager,
-                      "main-context", &main_context,
                       "port", &port,
                       NULL);
 
         context = g_initable_new (GUPNP_TYPE_CONTEXT,
                                   NULL,
                                   &error,
-                                  "main-context", main_context,
                                   "interface", LOOPBACK_IFACE,
                                   "port", port,
                                   NULL);
@@ -195,14 +192,12 @@ static void
 create_context_for_device (NMDevice *nm_device)
 {
         GError *error = NULL;
-        GMainContext *main_context;
         guint port;
         GVariant *value;
         char *iface;
         char *ssid = NULL;
 
         g_object_get (nm_device->manager,
-                      "main-context", &main_context,
                       "port", &port,
                       NULL);
 
@@ -233,7 +228,6 @@ create_context_for_device (NMDevice *nm_device)
         nm_device->context = g_initable_new (GUPNP_TYPE_CONTEXT,
                                              NULL,
                                              &error,
-                                             "main-context", main_context,
                                              "interface", iface,
                                              "network", ssid,
                                              "port", port,
@@ -274,20 +268,6 @@ ap_proxy_new_cb (GObject      *source_object,
         create_context_for_device (nm_device);
 }
 
-static GMainContext *
-push_thread_main_context (GUPnPNetworkManager *manager)
-{
-     GMainContext *main_context;
-
-     g_object_get (manager,
-		   "main-context", &main_context,
-		   NULL);
-
-     g_main_context_push_thread_default (main_context);
-
-     return main_context;
-}
-
 static void
 on_wifi_device_activated (NMDevice *nm_device)
 {
@@ -310,9 +290,6 @@ on_wifi_device_activated (NMDevice *nm_device)
         if (G_UNLIKELY (ap_path == NULL))
                 create_context_for_device (nm_device);
         else {
-                GMainContext *main_context;
-
-                main_context = push_thread_main_context (nm_device->manager);
                 g_dbus_proxy_new_for_bus (G_BUS_TYPE_SYSTEM,
                                           G_DBUS_PROXY_FLAGS_NONE,
                                           NULL,
@@ -322,7 +299,6 @@ on_wifi_device_activated (NMDevice *nm_device)
                                           nm_device->manager->priv->cancellable,
                                           ap_proxy_new_cb,
                                           nm_device);
-                g_main_context_pop_thread_default (main_context);
 	}
 
         g_variant_unref (value);
@@ -467,9 +443,6 @@ device_proxy_new_cb (GObject      *source_object,
 
         if (type == NM_DEVICE_TYPE_WIFI) {
                 const char *path;
-                GMainContext *main_context;
-
-                main_context = push_thread_main_context (manager);
 
                 path = g_dbus_proxy_get_object_path (nm_device->proxy);
                 g_dbus_proxy_new_for_bus (G_BUS_TYPE_SYSTEM,
@@ -481,7 +454,6 @@ device_proxy_new_cb (GObject      *source_object,
                                           manager->priv->cancellable,
                                           wifi_proxy_new_cb,
                                           nm_device);
-                g_main_context_pop_thread_default (main_context);
         } else
                 use_new_device (manager, nm_device);
 }
@@ -511,14 +483,12 @@ on_manager_signal (GDBusProxy *proxy,
 
         if (g_strcmp0 (signal_name, "DeviceAdded") == 0) {
                 char *device_path = NULL;
-                GMainContext *main_context;
 
                 g_variant_get_child (parameters, 0, "o", &device_path);
                 if (G_UNLIKELY (device_path == NULL))
                         return;
 
 
-                main_context = push_thread_main_context (manager);
                 g_dbus_proxy_new_for_bus (G_BUS_TYPE_SYSTEM,
                                           G_DBUS_PROXY_FLAGS_NONE,
                                           NULL,
@@ -528,7 +498,6 @@ on_manager_signal (GDBusProxy *proxy,
                                           manager->priv->cancellable,
                                           device_proxy_new_cb,
                                           manager);
-                g_main_context_pop_thread_default (main_context);
                 g_free (device_path);
         } else if (g_strcmp0 (signal_name, "DeviceRemoved") == 0) {
                 GList *device_node;
@@ -570,7 +539,6 @@ get_devices_cb (GObject      *source_object,
         GVariantIter *device_iter;
         char* device_path;
         GError *error = NULL;
-        GMainContext *main_context;
 
         manager = GUPNP_NETWORK_MANAGER (user_data);
 
@@ -587,7 +555,6 @@ get_devices_cb (GObject      *source_object,
         }
 
         g_variant_get_child (ret, 0, "ao", &device_iter);
-        main_context = push_thread_main_context (manager);
         while (g_variant_iter_loop (device_iter, "o", &device_path))
                 g_dbus_proxy_new_for_bus (G_BUS_TYPE_SYSTEM,
                                           G_DBUS_PROXY_FLAGS_NONE,
@@ -598,7 +565,6 @@ get_devices_cb (GObject      *source_object,
                                           manager->priv->cancellable,
                                           device_proxy_new_cb,
                                           user_data);
-        g_main_context_pop_thread_default (main_context);
         g_variant_iter_free (device_iter);
 
         g_variant_unref (ret);
@@ -607,18 +573,12 @@ get_devices_cb (GObject      *source_object,
 static void
 schedule_loopback_context_creation (GUPnPNetworkManager *manager)
 {
-        GMainContext *main_context;
-
-        g_object_get (manager,
-                      "main-context", &main_context,
-                      NULL);
-
         /* Create contexts in mainloop so that is happens after user has hooked
          * to the "context-available" signal.
          */
         manager->priv->idle_context_creation_src = g_idle_source_new ();
         g_source_attach (manager->priv->idle_context_creation_src,
-            main_context);
+                         g_main_context_get_thread_default ());
         g_source_set_callback (manager->priv->idle_context_creation_src,
                                create_loopback_context,
                                manager,
@@ -630,7 +590,6 @@ static void
 init_network_manager (GUPnPNetworkManager *manager)
 {
         GUPnPNetworkManagerPrivate *priv;
-        GMainContext *main_context;
         GError *error;
 
         priv = manager->priv;
@@ -659,7 +618,6 @@ init_network_manager (GUPnPNetworkManager *manager)
                           manager);
 
 
-        main_context = push_thread_main_context (manager);
         g_dbus_proxy_call (priv->manager_proxy,
                            "GetDevices",
                            NULL,
@@ -668,7 +626,6 @@ init_network_manager (GUPnPNetworkManager *manager)
                            priv->cancellable,
                            get_devices_cb,
                            manager);
-        g_main_context_pop_thread_default (main_context);
 }
 
 static void
@@ -754,7 +711,7 @@ gupnp_network_manager_class_init (GUPnPNetworkManagerClass *klass)
 }
 
 gboolean
-gupnp_network_manager_is_available (GMainContext *main_context)
+gupnp_network_manager_is_available ()
 {
         GDBusProxy *dbus_proxy;
         GVariant *ret_values;
